@@ -1,7 +1,7 @@
-import os
-
 import telegram
-from dotenv import load_dotenv
+from scrapper_boilerplate.warnings import disable_warnings
+
+disable_warnings()
 
 
 class TelegramBot:
@@ -11,21 +11,38 @@ class TelegramBot:
     - to access token, create bot in @botFather and paste the token
     """ 
 
-    def __init__(self, root_path, chat_id:list):
+    def __init__(self, auth_token:str, chat_id:list):
         print('> iniciando módulo do telegram!')
-        load_dotenv(os.path.join(root_path, '.env'))
-        self.TOKEN = os.environ.get("TELEGRAM_TOKEN")
-        self.bot = telegram.Bot(token=self.TOKEN)
+        self.TOKEN = auth_token
         self.CHAT_ID = chat_id
+        self.bot = telegram.Bot(token=self.TOKEN)
 
     def send_message(self, msg):
         try:
             print('> Enviando mensagem...')
             for chat in self.CHAT_ID:
-                self.bot.sendMessage(chat_id=chat, text=msg)
+                self.bot.sendMessage(chat_id=int(chat), text=msg)
 
         except Exception as error:
             print(f'> [ERRO] ao enviar mensagem! {error} ')
 
         else:
-            print('> Mensagem enviada com sucesso!')
\ No newline at end of file
+            print('> Mensagem enviada com sucesso!')
+            return True
+
+    def send_file(self, filename):
+        """
+        send a file to telegram
+        """
+        try:
+            document = open(filename, 'rb')
+            for ids in self.CHAT_ID:
+                self.bot.send_document(int(ids), document)
+
+        except Exception as error:
+            print(f'> [ERRO] ao enviar arquivo! {error} ')
+            raise
+
+        else:
+            print('> Arquivo enviado com sucesso!')
+            return True
